### R code from vignette source 'msSurv.Rnw'

###################################################
### code chunk number 1: prelim
###################################################
options(prompt="R> ", continue = "+  ", useFancyQuotes = FALSE)


###################################################
### code chunk number 2: <msSurv
###################################################
library("msSurv")


###################################################
### code chunk number 3: RCdata
###################################################
data("RCdata")


###################################################
### code chunk number 4: ex1dat
###################################################
RCdata[70:76, ]


###################################################
### code chunk number 5: stateinfo
###################################################
Nodes <- c("1", "2", "3", "4", "5")
Edges <- list("1" = list(edges = c("2", "3")),
              "2" = list(edges = c("4", "5")),
              "3" = list(edges = NULL),
              "4" = list(edges = NULL),
              "5" = list(edges = NULL))


###################################################
### code chunk number 6: tree
###################################################
treeobj <- new("graphNEL", nodes = Nodes, edgeL = Edges,
           edgemode = "directed")


###################################################
### code chunk number 7: exrtcens
###################################################
ex1 <- msSurv(RCdata, treeobj, bs = TRUE)


###################################################
### code chunk number 8: printex1
###################################################
print(ex1)


###################################################
### code chunk number 9: msSurv.Rnw:668-669
###################################################
Pst(ex1, s = 1, t = 3.1)


###################################################
### code chunk number 10: addvar (eval = FALSE)
###################################################
## Pst(ex1, s = 1, t = 3.1, covar = TRUE)


###################################################
### code chunk number 11: msSurv.Rnw:687-688
###################################################
SOPt(ex1, t = 0.85)


###################################################
### code chunk number 12: msSurv.Rnw:698-699 (eval = FALSE)
###################################################
## SOPt(ex1, t = 0.85, covar = TRUE)


###################################################
### code chunk number 13: EntryExit
###################################################
EntryExit(ex1, t = 1)


###################################################
### code chunk number 14: EntryExitObjs
###################################################
norm.dist <- EntryExit(ex1, t = 1, covar = TRUE)
sub.dist  <- EntryExit(ex1, t = 1, norm = FALSE, covar = TRUE)


###################################################
### code chunk number 15: EntryExitOutput
###################################################
names(norm.dist)
names(sub.dist)


###################################################
### code chunk number 16: LTRCata
###################################################
data("LTRCdata")


###################################################
### code chunk number 17: head
###################################################
LTRCdata[489:494, ]


###################################################
### code chunk number 18: LTRCtree
###################################################
Nodes <- c("1", "2", "3")
Edges <- list("1" = list(edges = c("2", "3")),
              "2" = list(edges = c("3")),
              "3" = list(edges = NULL))
LTRCtree <- new("graphNEL", nodes = Nodes, edgeL = Edges,
                edgemode = "directed")


###################################################
### code chunk number 19: exrtcenslt
###################################################
ex2 <- msSurv(LTRCdata, LTRCtree, LT = TRUE)


###################################################
### code chunk number 20: msSurv.Rnw:859-860
###################################################
summary(ex2, digits = 2)


###################################################
### code chunk number 21: sumAll (eval = FALSE)
###################################################
## summary(ex2, all = TRUE)


###################################################
### code chunk number 22: sumSOP (eval = FALSE)
###################################################
## summary(ex2, trans.pr = FALSE, dist = FALSE)


###################################################
### code chunk number 23: configdat
###################################################
if (require("KMsurv")) {
    data("bmt")
    attach(bmt)

    ## NOTES
    ## ta = Time To Acute Graft-Versus-Host Disease
    ## tp = Time To Platelet Recovery (incorrect in help file for 'bmt')
    ## tc = Time To Chronic Graft-Versus-Host Disease
    ## da = Acute GVHD Indicator 1-Developed Acute GVHD 0-Never Developed Acute GVHD)
    ## dp = Platelet Recovery Indicator 1-Platelets Returned To Normal, 0-Platelets Never Returned to Normal
    ## dc = Chronic GVHD Indicator 1-Developed Chronic GVHD 0-Never Developed Chronic GVHD
    ## t2 = Disease Free Survival Time (Time To Relapse, Death Or End Of Study)
    ## t2 used for CENSORING time here

    ## Determining transitions from STATE 1 ###

    ## 1 -> 2 transition:
    ## aGVHD BEFORE platelets return to normal
    s1to2 <- which(ta < tp) #7
    data12 <- data.frame(id = s1to2, stop = ta[s1to2], start.stage = 1, end.stage = 2)

    ## 1 -> 3 transition:
    ## platelets return to normal BEFORE aGVHD (and before cGVHD ... )
    s1to3 <- which(tp < ta & tp < tc) #117
    data13 <- data.frame(id = s1to3, stop = tp[s1to3], start.stage = 1, end.stage = 3)
    ## censored individuals = death or relapse, use t2
    c1 <- which(t2 <= pmin(ta, tp)) ## 13
    data10 <- data.frame(id = c1, stop = t2[c1], start.stage = 1, end.stage = 0)


    ## Determining transitions from STATE 2 ###

    ## 2 -> 4 transition:
    ## Individuals who developed acute GVHD BEFORE platelets returned to normal AND
    ## platelets returned to normal BEFORE chronic GVHD AND not censored
    s2to4 <- which(ta < tp & tp < tc & tp < t2 & dp==1) ## 3 (20, 32, 107) OK
    data24 <- data.frame(id = s2to4, stop = tp[s2to4], start.stage = 2, end.stage = 4)

    ## 2 -> 5 transition:
    ## Individuals who developed acute GVHD before platelets return to normal AND
    ## develop chronic GVHD BEFORE platelets returned to normal AND not censored
    s2to5 <- which(ta < tp & tc < tp & tc < t2 & dc==1)
    data25 <- data.frame(id = s2to5, stop = tc[s2to5], start.stage = 2, end.stage = 5)

    ## 2 -> 0 transition (censored):
    c2 <- which(t2 > ta & t2 <= pmin(tp, tc)) ## 2,  censored in stage 2
    data20 <- data.frame(id = c2, stop = t2[c2], start.stage = 2, end.stage = 0)


    ## Determining transitions from STATE 3 ##

    ## 3 -> 4 transition:
    ## normal platelets BEFORE aGVHD, then aGVHD BEFORE end of study and cGVHD
    s3to4 <- which(tp < ta & ta < tc & ta < t2  & da==1 ) ## 19 OK
    ## 11 of these have dc=1
    data34 <- data.frame(id = s3to4, stop = ta[s3to4], start.stage = 3, end.stage = 4)

    ## 3 -> 5 transition:
    ## normal platelets before aGVHD, and cGVHD BEFORE end of study and aGVHD
    s3to5 <- which(tp < ta & tc < ta & tc < t2 & dc==1) ## 44
    data35 <- data.frame(id = s3to5, stop = tc[s3to5], start.stage = 3, end.stage = 5)

    ## 3 -> 0 transition (censored):
    c3 <- which(t2 > tp & t2 <= pmin(ta, tc))
    data30 <- data.frame(id = c3, stop = t2[c3], start.stage = 3, end.stage = 0)


    ## Determining transitions from STATE 4 ##

    ## 4 -> 5 transition:
    ## TWO ways to reach state 4, via state 2 or state 3
    ## via state 2 to 4 to 5
    s4to5a <- which((ta < tp & tp < tc & tp < t2 & dp==1) & tc < t2 & dc==1) ## 1
    ## via state 3 to 4 to 5
    s4to5b <- which((tp < ta & ta < tc & ta < t2  & da==1) & tc < t2 & dc==1) ## 11
    data45a <- data.frame(id = s4to5a, stop = tc[s4to5a], start.stage = 4, end.stage = 5)
    data45b <- data.frame(id = s4to5b, stop = tc[s4to5b], start.stage = 4, end.stage = 5)

    ## 4 -> 0 transition
    ## via state 2 to 4 to 5
    c4a <- which((ta < tp & tp < tc & tp < t2 & dp==1) & t2 <= tc)
    ## via state 3 to 4 to 5
    c4b <- which((tp < ta & ta < tc & ta < t2  & da==1) & t2 <= tc)
    ## identical to below ...
    ## c4a <-  s2to4[which(!(s2to4%in%s4to5a))] ## 2 (20, 107)
    ## c4b <-  s3to4[which(!(s3to4%in%s4to5b))]
    data40a <- data.frame(id = c4a, stop = t2[c4a], start.stage = 4, end.stage = 0)
    data40b <- data.frame(id = c4b, stop = t2[c4b], start.stage = 4, end.stage = 0)


    ## Combining to make a DATASET ready for msSurv ##
    data.sdc <- rbind(data10, data12, data13, data20, data24, data25,
                      data30, data34, data35, data40a, data40b, data45a, data45b)
    data.sdc <- data.sdc[order(data.sdc$id),  ]

    ## Remove row with STOP time of 0
    ## ID = 124 - basically individual STARTS in stage 3 (platelets normal at t = 0)
    data.sdc <- data.sdc[-which(data.sdc$stop==0),  ]

    detach(bmt)
}



###################################################
### code chunk number 24: depdataframe
###################################################
if(exists("data.sdc")) head(data.sdc)


###################################################
### code chunk number 25: deptree
###################################################
Nodes <- c("1", "2", "3", "4", "5")
Edges <- list("1" = list(edges = c("2", "3")),
              "2" = list(edges = c("4", "5")),
              "3" = list(edges = c("4", "5")),
              "4" = list(edges = c("5")),
              "5" = list(edges = NULL))
deptree <- new("graphNEL", nodes = Nodes, edgeL = Edges,
               edgemode = "directed")


###################################################
### code chunk number 26: depcall
###################################################
if(exists("data.sdc"))
    DepEx <- msSurv(data.sdc, deptree, cens.type = "dep", bs = TRUE)


###################################################
### code chunk number 27: ex3plot
###################################################
if(exists("DepEx")) plot(DepEx)


###################################################
### code chunk number 28: plotst2 (eval = FALSE)
###################################################
## if(exists("DepEx")) plot(DepEx, state = "2")


###################################################
### code chunk number 29: plotst23 (eval = FALSE)
###################################################
## if(exists("DepEx")) plot(DepEx, state = c("2","3"))


###################################################
### code chunk number 30: entryplot1
###################################################
if(exists("DepEx"))
    plot(DepEx, plot.type = "entry.norm", states = "ALL")


###################################################
### code chunk number 31: entryplot2 (eval = FALSE)
###################################################
## if(exists("DepEx"))
##     plot(DepEx, plot.type = "entry.norm", states = c("2","3"))


###################################################
### code chunk number 32: exitplot1
###################################################
if(exists("DepEx"))
    plot(DepEx, plot.type = "exit.norm")


###################################################
### code chunk number 33: exitplot2 (eval = FALSE)
###################################################
## if(exists("DepEx"))
##     plot(DepEx, plot.type = "exit.norm", states = "1")


###################################################
### code chunk number 34: ex3transplot
###################################################
if(exists("DepEx"))
    plot(DepEx, plot.type = "transprob")


###################################################
### code chunk number 35: ex3transplot1 (eval = FALSE)
###################################################
## if(exists("DepEx"))
##     plot(DepEx, plot.type = "transprob", trans = c("1 2", "1 3"))


